[−][src]Enum git_credential::Error
Errors that can occur while reading or writing the git credential format
Variants
ReadErrorIndicates that there was an error while reading from the given Reader
Fields of ReadError
source: ErrorThe underlying io error causing the issue
WriteErrorIndicates that there was an error while writing to the given Writer
Fields of WriteError
source: ErrorThe underlying io error causing the issue
ParseErrorIndicates that the format received did not correspond to the one specified in git-credential[1] .
Fields of ParseError
value: StringThe value that could not be parsed
source: ParseErrorThe underlying io error causing the issue